Function syntax::parse::byte_litUnstable
[-] [+]
[src]
pub fn byte_lit(lit: &str) -> (u8, usize)
Parse a string representing a byte literal into its final form. Similar to char_lit
pub fn byte_lit(lit: &str) -> (u8, usize)
Parse a string representing a byte literal into its final form. Similar to char_lit
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).